BinaryCopyInWriter

Struct BinaryCopyInWriter 

pub struct BinaryCopyInWriter<'a> { /* private fields */ }
A type which serializes rows into the PostgreSQL binary copy format.

The copy must be explicitly completed via the finish method. If it is not, the copy will be aborted.

Implementations

Source

impl<'a> BinaryCopyInWriter<'a>

pub fn new(writer: CopyInWriter<'a>, types: &[Type]) -> BinaryCopyInWriter<'a>

Creates a new writer which will write rows of the provided types.

pub fn write(&mut self, values: &[&(dyn ToSql + Sync)]) -> Result<(), Error>

Writes a single row.

Panics

Panics if the number of values provided does not match the number expected.

pub fn write_raw<P, I>(&mut self, values: I) -> Result<(), Error>
where P: BorrowToSql, I: IntoIterator<Item = P>, I::IntoIter: ExactSizeIterator,

A maximally-flexible version of write.

Panics

Panics if the number of values provided does not match the number expected.

pub fn finish(self) -> Result<u64, Error>

Completes the copy, returning the number of rows added.

This method must be used to complete the copy process. If it is not, the copy will be aborted.